const secretService = require('@siemens-src/parameter-store-wrapper');
const publicPort = parseInt(process.env.META_API_PUBLIC_PORT || 5000, 10);
const requestLoggerLevel = process.env.META_API_REQUEST_LOGGER_LEVEL || "combined";
const awsRegion = process.env.AWS_REGION_INFO || "ap-south-1";
const parameterStoreOptions = {
  "region": awsRegion
};

if (process.env.ACCESS_KEY_ID && process.env.SECRET_ACCESS_KEY && process.env.SESSION_TOKEN) {
  Object.assign(parameterStoreOptions, {
    "accessKeyId": process.env.ACCESS_KEY_ID,
    "secretAccessKey": process.env.SECRET_ACCESS_KEY,
    "sessionToken": process.env.SESSION_TOKEN
  });
}

const PARAMETER_STORE = {
  "NAME": process.env.POSTGRE_DB_NAME || "POSTGRE_DB_NAME", // "frwdb",
  "USERNAME": process.env.POSTGRE_DB_USERNAME || "POSTGRE_DB_USERNAME", // "frwuser",
  "PASSWORD": process.env.POSTGRE_DB_PASSWORD || "POSTGRE_DB_PASSWORD", // "test123456",
  "HOST": process.env.POSTGRE_DB_HOST || "POSTGRE_DB_HOST" // "testfrw.cq8nz7qu1f61.eu-central-1.rds.amazonaws.com",
};

// const PARAMETER_STORE = {
//   "NAME": process.env.POSTGRE_DB_NAME || "frwdb",
//   "USERNAME": process.env.POSTGRE_DB_USERNAME || "frwsandboxmu",
//   "PASSWORD": process.env.POSTGRE_DB_PASSWORD || "frwsandboxmu",
//   "HOST": process.env.POSTGRE_DB_HOST || "frw-sandbox-pg.ctjleurv3bvc.eu-central-1.rds.amazonaws.com"
// };

const keys = Object.keys(PARAMETER_STORE);
function getKeyByValue(object, value) {
  return keys.find(key => object[key] === value);
}
const getParameterDetails = () => {
  const paramStoreKeys = Object.values(PARAMETER_STORE);
  const pmStoreDetails = secretService.getSecretService().getParameters(paramStoreKeys, parameterStoreOptions);
  const dbDeatails = {};
  pmStoreDetails.Parameters.map(item => {
    const key = getKeyByValue(PARAMETER_STORE, item.Name);
    dbDeatails[key] = item.Value;
  });
  return dbDeatails;
};


const accessParamters =  process.env.ACCESS_PARAMETER_STORE || "true";
const paramStoreValues = JSON.parse(accessParamters) !== false ? getParameterDetails() : PARAMETER_STORE;

const POSTGRE_DB = {
    "NAME": paramStoreValues.NAME,
    "USERNAME": paramStoreValues.USERNAME,
    "PASSWORD": paramStoreValues.PASSWORD,
    "HOST": paramStoreValues.HOST,
    "PORT": process.env.POSTGRE_DB_PORT || "5432",
    "idleTimeoutMillis": process.env.POSTGRE_DB_IDLE_CONNECTION_TIMEOUT || 600000,
    "max": process.env.POSTGRE_DB_MAX_CONNECTION || 50,
    "schema": process.env.schema || "pgdata_ep"
  };

const config = {
  "requestLoggerLevel": requestLoggerLevel,
  "PORT": publicPort,
  'API_VERSION': process.env.API_VERSION || '/v1',
  POSTGRE_DB,
  "AWS_REGION_INFO": awsRegion,
  'FILE_PATH_PREFIX': process.env.FILE_PATH_PREFIX || 'Data/Common/EPR_WPF/',
  "BUCKET_NAME": process.env.S3_BUCKET_NAME || "frw-sandbox-attachments",
  "PRIVATE_BUCKET_NAME": process.env.PRIVATE_BUCKET_NAME || "frw-sandbox-attachments-internal",
};

module.exports = exports = config;