const WorflowStep = require('./src');
const InstanceHandler = require('./src/instanceHandler');

/** 
 * @description Lambda got triggered when payload comes to S3
 * @param {Object} event payload for workflow step lambda
 */
exports.handler = async (event) => {
    // instance for InstanceHandler
    const instanceHandler = new InstanceHandler();
    // Initiate all the classes
    const stepExecutionService = instanceHandler.GetStepExecutionServiceInstance(event);
    // Exceptional handling for execution of lambda
    const worflowStep = new WorflowStep(stepExecutionService, event);
    // Execute current step
    const _response = await worflowStep.executeCurrentStep();
    // Save final payload back to s3
    const _result = await worflowStep.savePayloadToExecuteEngine(_response);
    return _result;
};

// Commented test data

// var obj = {
//     "reportId": "238170000104",
//     "data": {
//         "operation": "2"
//     },
//     "data1": {
//         "historyData": [
//             {
//                 "column": "job_num",
//                 "value": "12344",
//                 "type": "string"
//             }, {
//                 "column": "report_id",
//                 "value": "238170000104",
//                 "type": "number"
//             }, {
//                 "column": "operation_pk",
//                 "value": "11",
//                 "type": "number"
//             }, {
//                 "column": "from_status",
//                 "value": "23",
//                 "type": "number"
//             }, {
//                 "column": "to_status",
//                 "value": "24",
//                 "type": "number"
//             }
//         ],
//         "insertPDFData": {
//             cellData: [{
//                 column: 'pdf_report_pk',
//                 value: `nextval('pgdata_ep.ep_report_pdf_sequence')`,
//                 type: 'number'
//             }, {
//                 column: 'master_pk',
//                 value: "238170000104",
//                 type: 'number'
//             }, {
//                 column: 'seq_num',
//                 value: 4,
//                 type: 'number'
//             }, {
//                 column: 'file_name',
//                 value: 'test_data',
//                 type: 'string'
//             }, {
//                 column: 'current_status_pk',
//                 value: 3,
//                 type: 'number'
//             }, {
//                 column: 'view_report_pdf_link_pk',
//                 value: 1,
//                 type: 'number'
//             }, {
//                 column: 'possible_rejected_status_pk',
//                 value: 'null',
//                 type: 'number'
//             }, {
//                 column: 'is_valid',
//                 value: 1,
//                 type: 'number'
//             },
//             {
//                 column: 'create_date',
//                 value: 'now()',
//                 type: 'date'
//             },
//             {
//                 column: 'create_userid',
//                 value: "SYSTEM",
//                 type: 'string'
//             },
//             {
//                 column: 'lst_upd_date',
//                 value: 'now()',
//                 type: 'date'
//             },
//             {
//                 column: 'lst_upd_userid',
//                 value: 'SYSTEM',
//                 type: 'string'
//             },
//             {
//                 column: 'link_suffix',
//                 value: '_TEST',
//                 type: 'string'
//             }]
//         },
//         "updateReportData": {
//             "cellData": [
//                 {
//                     "column": "CUSTOMER_ACCESS",
//                     "value": "No",
//                     "type": "string"
//                 },
//                 {
//                     "column": "lst_upd_date",
//                     "value": "now()"
//                 },
//                 {
//                     "column": "lst_upd_userid",
//                     "value": "SYSTEM",
//                     "type": "string"
//                 }
//             ],
//             "conditions": [
//                 {
//                     "column": "master_pk",
//                     "value": "238170000104",
//                     "type": "number"
//                 }
//             ]
//         }
//     },
//     "result": "2"
// }

// exports.handler(obj);