/**
 * @description Represents query builder for database
 * @class
 */
class QueryBuilder {

  constructor() { }

  /**
   * @description Prepare query for function 
   * @param {string} functionName
   * @param {Array} params
   */
  selectFunction(functionName, params) {
    var query = `SELECT * FROM ${functionName}`;
    if (!!params && params.length) {
      query += `(${params.join(` , `)})`;
    }
    return query;
  }

  /**
   * @description Prepare update query for given table
   * @param {string} tableName 
   * @param {Array<JSON>} cellData 
   * @param {Array<JSON>} conditions 
   */
  buildUpdateQuery(tableName, cellData, conditions) {
    let _query = `UPDATE ${tableName} SET `;
    // Add column values
    for (let i = 0; i < cellData.length; i++) {
      const _value = cellData[i].type === "string" ? `'${cellData[i].value}'` : cellData[i].value;
      _query += `${cellData[i].column} = ${_value} ${i !== cellData.length - 1 ? ',' : ''}`;
    }
    // Add conditions
    _query = conditions.length ? _query + `WHERE ` : '';
    for (let i = 0; i < conditions.length; i++) {
      const _value = conditions[i].type === "string" ? `'${conditions[i].value}'` : conditions[i].value;
      _query += `${conditions[i].column} = ${_value} `;
    }
    return _query;
  }

  /**
   * @description Build history insert query
   * @param {string} functionName 
   * @param {Array} historyData 
   */
  buildHistoryFuncQuery(functionName, historyData) {
    let _historyFunction = functionName;
    for (let i = 0; i < historyData.length; i++) {
      const _col = historyData[i].column;
      const _value = historyData[i].type === "string" ? `'${historyData[i].value}'` : historyData[i].value;
      const _reg = new RegExp(_col, "g");
      _historyFunction = _historyFunction.replace(_reg, _value);
    }
    return `SELECT * FROM ${_historyFunction}`;
  }

  buildPDFQuery(tableName, PDFData, query) {
    let temp_query = query.replace(/table_name/g, tableName);
    for (let i = 0; i < PDFData.length; i++) {
      const _col = `#${PDFData[i].column}`;
      const _value = PDFData[i].type === "string" ? `'${PDFData[i].value}'` : PDFData[i].value;
      const _reg = new RegExp(_col, "g");
      temp_query = temp_query.replace(_reg, _value);
    }
    return temp_query;
  }

  buildGetQuery(tableName, reportId) {
    var query = `SELECT * FROM ${tableName} where master_pk=${reportId} order by create_date`;
    return query;
  }
}

module.exports = QueryBuilder;